@@ -597,16 +597,18 @@ void move_IC_in_win(ClientState *cs)
    dbg("move_IC_in_win %d,%d\n", inpx, inpy);
 
 #if UNIX
-   XWindowAttributes att;
-   XGetWindowAttributes(dpy, inpwin, &att);
-// chrome window is override_redirect
-//   if (att.override_redirect)
-//     return;
+	if (isX11()) {
+	   XWindowAttributes att;
+	   XGetWindowAttributes(dpy, inpwin, &att);
+	// chrome window is override_redirect
+	//   if (att.override_redirect)
+	//     return;
 
-   if (inpx >= att.width)
-     inpx = att.width - 1;
-   if (inpy >= att.height)
-     inpy = att.height - 1;
+	   if (inpx >= att.width)
+		 inpx = att.width - 1;
+	   if (inpy >= att.height)
+		 inpy = att.height - 1;
+	}
 #else
    if (inpwin) {
      RECT rect;
@@ -701,7 +703,7 @@ void destroy_tray()
   else
   if (current_gcin_win32_icon==GCIN_TRAY_UNIX)
     destroy_tray_icon();
-#if USE_INDICATOR
+#if USE_INDICATOR || USE_AY_INDICATOR
   else
     destroy_tray_indicator();
 #endif
@@ -730,7 +732,7 @@ void disp_tray_icon()
   else
   if (gcin_win32_icon==GCIN_TRAY_UNIX)
     load_tray_icon();
-#if USE_INDICATOR
+#if USE_INDICATOR || USE_AY_INDICATOR
   else
     load_tray_icon_indicator();
 #endif
@@ -936,6 +938,9 @@ void toggle_half_full_char_sub()
 	  return;
 #endif
 
+  if (!current_CS)
+    return;
+
   if (current_method_type() == method_type_TSIN && current_CS->im_state == GCIN_STATE_CHINESE) {
     tsin_toggle_half_full();
   }
@@ -1819,7 +1824,7 @@ int pho_get_preedit(char *str, GCIN_PREEDIT_ATTR attr[], int *cursor, int *sub_c
 
 int gcin_get_preedit(ClientState *cs, char *str, GCIN_PREEDIT_ATTR attr[], int *cursor, int *comp_flag)
 {
-//  dbg("gcin_get_preedit %x\n", current_CS);
+  dbg("gcin_get_preedit %x\n", current_CS);
   if (!current_CS) {
 empty:
 //    dbg("empty\n");
