@@ -127,13 +127,13 @@ void load_setttings()
   gcin_win32_icon = GCIN_TRAY_WIN32;
 #else
   gcin_win32_icon = get_gcin_conf_int(GCIN_WIN32_ICON,
-#if USE_INDICATOR
+#if USE_INDICATOR || USE_AY_INDICATOR
   GCIN_TRAY_INDICATOR
 #else
   GCIN_TRAY_WIN32
 #endif
   );
-#if !USE_INDICATOR
+#if !(USE_INDICATOR||USE_AY_INDICATOR)
   if (gcin_win32_icon == GCIN_TRAY_INDICATOR)
     gcin_win32_icon = GCIN_TRAY_WIN32;
 #endif
