@@ -31,7 +31,7 @@ static GtkWidget *opt_tray;
 static GtkWidget *label_cursor;
 extern gboolean button_order;
 
-#if USE_INDICATOR
+#if USE_INDICATOR || USE_AY_INDICATOR
 static struct {
   char *name;
   int key;
@@ -147,7 +147,7 @@ static gboolean cb_appearance_conf_ok( GtkWidget *widget,
   save_gcin_conf_int(GCIN_INNER_FRAME, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_gcin_inner_frame)));
 #if TRAY_ENABLED
   save_gcin_conf_int(GCIN_STATUS_TRAY, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_gcin_status_tray)));
-#if USE_INDICATOR
+#if USE_INDICATOR || USE_AY_INDICATOR
  save_gcin_conf_int(GCIN_WIN32_ICON,
                      tray_options[gtk_combo_box_get_active(GTK_COMBO_BOX(opt_tray))].key);
 #else
@@ -425,7 +425,7 @@ static gboolean cb_appearance_help( GtkWidget *widget,
   return TRUE;
 }
 
-#if USE_INDICATOR
+#if USE_INDICATOR || USE_AY_INDICATOR
 static int get_currnet_tray_option_idx()
 {
   int i;
@@ -644,7 +644,7 @@ void create_appearance_conf_window()
 
   GtkWidget *hbox_label_gcin_status_tray_windows_style = gtk_hbox_new(FALSE, 0);
 #if UNIX
-#if USE_INDICATOR
+#if USE_INDICATOR || USE_AY_INDICATOR
   gtk_box_pack_start (GTK_BOX(hbox_gcin_status_tray), create_status_icon_opts(), FALSE, FALSE, 20);
 #else
   gtk_box_pack_start (GTK_BOX(hbox_gcin_status_tray), hbox_label_gcin_status_tray_windows_style, FALSE, FALSE, 20);
