@@ -496,7 +496,7 @@ gboolean delayed_start_cb(gpointer data)
     else
     if (gcin_win32_icon==GCIN_TRAY_UNIX)
       init_tray();
-#if USE_INDICATOR
+#if USE_INDICATOR || USE_AY_INDICATOR
     else
       init_tray_indicator();
 #endif
@@ -659,7 +659,8 @@ static char button_rc[]="style \"button\"\n"
 
 #if UNIX
   dpy = GDK_DISPLAY();
-  root=DefaultRootWindow(dpy);
+  if (isX11())
+	root=DefaultRootWindow(dpy);
 #endif
   get_dpy_xyl();
   g_signal_connect(gdk_screen_get_default(),"size-changed", G_CALLBACK(screen_size_changed), NULL);
@@ -671,7 +672,8 @@ static char button_rc[]="style \"button\"\n"
 #endif
 
 #if USE_XIM
-  open_xim();
+  if (isX11())
+	open_xim();
 #endif
 
 #if UNIX
