@@ -13,7 +13,7 @@
 #include "tsin.h"
 #include "gst.h"
 
-
+u_int64_t gkeys[MAX_SELKEY];
 extern gboolean test_mode;
 gboolean gtab_phrase_on();
 gboolean gtab_disp_partial_match_on(), gtab_vertical_select_on(), gtab_pre_select_on(), gtab_unique_auto_send_on(), gtab_press_full_auto_send_on();
@@ -223,7 +223,7 @@ void lookup_gtabn(char *ch, char *out)
 
 void lookup_gtab(char *ch)
 {
-  char tt[CH_SZ+1];
+  char tt[CH_SZ*4+1];
   utf8cpy(tt, ch);
   lookup_gtabn(tt, NULL);
 }
@@ -231,12 +231,11 @@ void lookup_gtab(char *ch)
 
 void lookup_gtab_out(char *ch, char *out)
 {
-  char tt[CH_SZ+1];
+  char tt[CH_SZ*4+1];
   utf8cpy(tt, ch);
   lookup_gtabn(tt, out);
 }
 
-
 char *b1_cat(char *s, char c)
 {
   char t[2];
@@ -554,6 +553,7 @@ static gboolean tblidx_to_str(int tblidx, char out[])
 
 static gboolean load_seltab(int tblidx, int seltabidx)
 {
+  gkeys[seltabidx] = CONVT2(cur_inmd, tblidx);
   return tblidx_to_str(tblidx, seltab[seltabidx]);
 }
 
@@ -1408,7 +1408,7 @@ next_page:
 direct_select:
             if (gtab_phrase_on_() && poo.same_pho_query_state != SAME_PHO_QUERY_gtab_input) {
               dbg("ins ggg.kval %x\n", ggg.kval);
-              insert_gbuf_cursor1_cond(seltab[ggg.sel1st_i], ggg.kval, ggg.exa_match);
+              insert_gbuf_cursor1_cond(seltab[ggg.sel1st_i], gkeys[ggg.sel1st_i], ggg.exa_match);
             }
             else {
 			  flush_en();
@@ -1597,7 +1597,7 @@ keypad_proc:
 #endif
         if (seltab[ggg.sel1st_i][0]) {
           if (gtab_phrase_on_() && poo.same_pho_query_state != SAME_PHO_QUERY_gtab_input)
-            insert_gbuf_cursor1_cond(seltab[ggg.sel1st_i], ggg.kval, ggg.exa_match);
+            insert_gbuf_cursor1_cond(seltab[ggg.sel1st_i], gkeys[ggg.sel1st_i], ggg.exa_match);
           else {
             flush_en();
             putstr_inp(seltab[ggg.sel1st_i]);  /* select 1st */
@@ -1635,7 +1635,7 @@ keypad_proc:
 				if (ggg.gtab_buf_select && poo.same_pho_query_state != SAME_PHO_QUERY_gtab_input)
 				  set_gbuf_c_sel(vv);
 				else
-				  insert_gbuf_cursor1_cond(seltab[vv], ggg.kval, ggg.exa_match);
+				  insert_gbuf_cursor1_cond(seltab[vv], gkeys[vv], ggg.exa_match);
 			  }
 			  else {
 				flush_en();
@@ -1654,7 +1654,7 @@ keypad_proc:
       if (seltab[ggg.sel1st_i][0] && !ggg.wild_mode &&
            (gtab_full_space_auto_first||ggg.spc_pressed||ggg.last_full) ) {
         if (gtab_phrase_on_() && poo.same_pho_query_state != SAME_PHO_QUERY_gtab_input)
-          insert_gbuf_cursor1_cond(seltab[ggg.sel1st_i], ggg.kval, ggg.exa_match);
+          insert_gbuf_cursor1_cond(seltab[ggg.sel1st_i], gkeys[ggg.sel1st_i], ggg.exa_match);
         else {
 		  flush_en();
           putstr_inp(seltab[ggg.sel1st_i]);  /* select 1st */
@@ -1876,7 +1876,7 @@ YYYY:
 
       if (seltab[vv][0]) {
         if (gtab_phrase_on_() && poo.same_pho_query_state != SAME_PHO_QUERY_gtab_input)
-          insert_gbuf_cursor1_cond(seltab[vv], ggg.kval, ggg.exa_match);
+          insert_gbuf_cursor1_cond(seltab[vv], gkeys[vv], ggg.exa_match);
         else {
 		  flush_en();
           putstr_inp(seltab[vv]);
@@ -2070,7 +2070,7 @@ next_pg:
     if (ggg.defselN==1 && !ggg.more_pg) {
       if (ggg.spc_pressed || full_send || gtab_unique_auto_send_on()) {
         if (gtab_phrase_on_() && poo.same_pho_query_state != SAME_PHO_QUERY_gtab_input)
-          insert_gbuf_cursor1_cond(seltab[0], ggg.kval, ggg.exa_match);
+          insert_gbuf_cursor1_cond(seltab[0], gkeys[0], ggg.exa_match);
         else {
 		  flush_en();
           putstr_inp(seltab[0]);
