@@ -8,11 +8,12 @@
 
 int html_browser(char *fname)
 {
+dbg("html_browser %s\n", fname);
 #if WIN32
   LONG r = (LONG)ShellExecuteA(NULL, "open", fname, NULL, NULL, SW_SHOWNORMAL);
   return r;
 #else
-#if 0
+#if 1
   static char html_browse[]=GCIN_SCRIPT_DIR"/html-browser";
   char tt[256];
   sprintf(tt, "%s %s", html_browse, fname);
@@ -22,6 +23,8 @@ int html_browser(char *fname)
   GError *error;
   error = NULL;
   gtk_show_uri (gdk_screen_get_default (),  fname, gtk_get_current_event_time (), &error);
+
+  return 0;
 #endif
 #endif
 }
