@@ -66,7 +66,7 @@ HWND find_gcin_window()
 #include <io.h>
 #include <strsafe.h>
 
-bool sys_end_session;
+// bool sys_end_session;
 static HWND serverWnd;
 
 static bool start_gcin()
@@ -203,6 +203,8 @@ int is_special_user;
 GCIN_SHM gcin_open_shared_mem(int port);
 #endif
 
+static char execbin[]=GCIN_BIN_DIR"/gcin";
+
 static GCIN_client_handle *gcin_im_client_reopen(GCIN_client_handle *gcin_ch, Display *dpy)
 {
 #if WIN32
@@ -219,9 +221,9 @@ static GCIN_client_handle *gcin_im_client_reopen(GCIN_client_handle *gcin_ch, Di
 #if UNIX
   int sockfd=0;
   int servlen;
-  char *addr;
+  char *addr=NULL;
   Server_IP_port srv_ip_port;
-  u_char *pp;
+  u_char *pp=NULL;
 
   int uid = getuid();
   if (uid > 0 && uid < 500) {
@@ -246,6 +248,54 @@ static GCIN_client_handle *gcin_im_client_reopen(GCIN_client_handle *gcin_ch, Di
     goto next;
   }
 
+
+  if (!isX11()) { // ubuntu wayland
+	  dbg("wayland....\n");
+	struct sockaddr_un serv_addr;
+	bzero((char *) &serv_addr,sizeof(serv_addr));
+	serv_addr.sun_family = AF_UNIX;
+	char sock_path[128];
+
+    get_gcin_im_srv_sock_path(sock_path, sizeof(sock_path));	     
+    dbg("sock %s\n", sock_path);
+	strcpy(serv_addr.sun_path, sock_path);
+#ifdef SUN_LEN
+	servlen = SUN_LEN(&serv_addr);
+#else
+	servlen = strlen(serv_addr.sun_path) + sizeof(serv_addr.sun_family);
+#endif
+
+	if ((sockfd = socket(AF_UNIX, SOCK_STREAM, 0)) < 0) {
+		perror("cannot open socket");
+		goto tcp;
+	}
+	
+	if (connect(sockfd, (struct sockaddr *)&serv_addr, servlen) < 0) {
+		close(sockfd);
+		sockfd = 0;
+		if (!is_special_user && !getenv("GCIN_IM_CLIENT_NO_AUTO_EXEC")) {
+			dbg("connect failed ... try to start a new gcin server %s\n", execbin);
+			int pid;
+			if ((pid=fork())==0) {
+				putenv("GCIN_DAEMON=");
+				execl(execbin, "gcin", NULL);
+			} else {
+				int status;
+				// gcin will daemon()
+				waitpid(pid, &status, 0);
+			}		
+			
+			sleep(3);
+			if ((sockfd = socket(AF_UNIX, SOCK_STREAM, 0)) < 0) {
+				perror("cannot open socket");				
+				sockfd = 0;				
+			}					
+		}		 
+	}
+	dbg("sockfd:%d\n", sockfd);
+	goto next;	
+  }
+
   Atom gcin_addr_atom = get_gcin_addr_atom(dpy);
   Window gcin_win = None;
 
@@ -262,7 +312,7 @@ static GCIN_client_handle *gcin_im_client_reopen(GCIN_client_handle *gcin_ch, Di
     if (time(NULL) - exec_time > 1 /* && count < 5 */) {
       time(&exec_time);
       dbg("XGetSelectionOwner: old version of gcin or gcin is not running ??\n");
-      static char execbin[]=GCIN_BIN_DIR"/gcin";
+//      static char execbin[]=GCIN_BIN_DIR"/gcin";
       dbg("... try to start a new gcin server %s\n", execbin);
 
       int pid;
