@@ -191,7 +191,7 @@ void init_gcin_im_serv(Window win)
   servlen = strlen(serv_addr.sun_path) + sizeof(serv_addr.sun_family);
 #endif
 
-  dbg("-- %s\n",serv_addr.sun_path);
+  dbg("sock -- %s\n",serv_addr.sun_path);
   struct stat st;
 
   if (!stat(serv_addr.sun_path, &st)) {
