@@ -1,5 +1,5 @@
 typedef struct {
-  unich_t *name;
+  char *name;
   char *stock_id;
   void (*cb)(GtkCheckMenuItem *checkmenuitem, gpointer dat);
   int *check_dat;
