@@ -224,7 +224,8 @@ int inph_typ_pho_no_tone(KeySym newkey)
 //    dbg("zzzz\n");
 	if (!poo.typ_pho[0] && !poo.typ_pho[1] && !poo.typ_pho[2])
 		return PHO_STATUS_REJECT;
-    if (newkey==' ') {
+//    if (newkey==' ') 
+    {
 	  u_char mtyp_pho[4];
 	  int count;
 	  find_match_phos(mtyp_pho, &count, newkey);
@@ -261,13 +262,13 @@ int inph_typ_pho_no_tone(KeySym newkey)
 	  }
 
 #if 1
-      if (typ==1) {
-		if (poo.typ_pho[0]) {
+      if (typ==1||typ==2) {
+		if (poo.typ_pho[0] || (poo.typ_pho[1] && typ==2)) {
 			u_char mtyp_pho[4];
 			int count;
 			find_match_phos(mtyp_pho, &count, newkey);
 			if (!count) {
-				poo.typ_pho[1]=0;
+				poo.typ_pho[typ]=0;
 				insert=-1;
 				break;
 			}
