@@ -9,10 +9,12 @@ int qcmp_str(const void *aa, const void *bb)
   return strcmp(a->pinyin, b->pinyin);
 }
 
-int main()
+int main(int argc, char **argv)
 {
   FILE *fp;
-  char fnamein[]="pin-juyin.src";
+  char *fnamein="pin-juyin.src";
+  if (argc > 1)
+		fnamein=argv[1];
   PIN_JUYIN pinju[1024];
   short pinjuN=0;
 
@@ -51,7 +53,13 @@ int main()
   
   qsort(pinju, pinjuN, sizeof(PIN_JUYIN), qcmp_str);
 
-  char fnameout[]="pin-juyin.xlt";
+  char fnameout[32];
+  
+  strcpy(fnameout, fnamein);
+//  "pin-juyin.xlt";
+  char *p=strchr(fnameout, '.');
+  *p=0;
+  strcat(fnameout, ".xlt");
 
   if ((fp=fopen(fnameout, "wb"))==NULL)
     p_err("cannot create %s", fnameout);
