@@ -32,6 +32,46 @@ void set_is_chs();
 gboolean tsin_seek_ex(TSIN_HANDLE *ptsin_hand, void *pho, int plen, int *r_sti, int *r_edi, char *tone_mask);
 void load_tsin_entry_ex(TSIN_HANDLE *ptsin_hand, int idx, char *len, usecount_t *usecount, void *pho, u_char *ch);
 
+u_int32_t minUseCount;
+
+typedef struct {
+	u_char len;
+	phokey_t k[5];
+	char s[CH_SZ*5+1];
+	usecount_t uc;	
+} PRE5;	
+
+int qcmp_pre5(const void *aa, const void *bb) {
+	PRE5 *a=(PRE5*)aa;
+	PRE5 *b=(PRE5*)bb;
+	int d;
+	
+	if (d=((int)a->len - (int)b->len))
+		return d;
+		
+	for(int i=0;i<a->len;i++) 	
+	if (d=((int)a->k[i] - (int)b->k[i]))
+		return d;
+	return b->uc - a->uc;
+}	
+
+int qcmp_pre5_s(const void *aa, const void *bb) {
+	PRE5 *a=(PRE5*)aa;
+	PRE5 *b=(PRE5*)bb;
+	return strcmp(a->s, b->s);
+}	
+
+phokey_t get_first_pho(phokey_t k) {
+	phokey_t t = k & (31<<9);	
+	if (t)
+		return t;
+	t = k&(3<<7);
+	if (t)
+		return t;		
+	t= k&(15<<3);			
+	return t;	
+}	
+
 int main(int argc, char **argv)
 {
   FILE *fp;
@@ -49,6 +89,10 @@ int main(int argc, char **argv)
   char fname_tmp[128];
   char ts_user_fname[128];
   gboolean no_pho = FALSE;
+  int leq=0;
+  gboolean pre2=FALSE,pre3=FALSE,pre4=FALSE,pre5=FALSE;
+  PRE5 *p2ar;
+  int p2arN=0;
 
   if (getenv("NO_GTK_INIT")==NULL)
     gtk_init(&argc, &argv);
@@ -80,6 +124,33 @@ int main(int argc, char **argv)
       i++;
       no_pho = TRUE;
     } else
+    if (!strcmp(argv[i], "-muc")) {
+      if (i==argc-1 || argv[i+1][0]=='-' || atoi(argv[i+1])<0)
+        p_err("-muc need a number");
+      minUseCount = atoi(argv[i+1]);
+      i+=2;		
+      fprintf(stderr, "minUseCount:%d\n", minUseCount);
+    } else
+    if (!strcmp(argv[i], "-pre2")) {
+//	  fprintf(stderr, "-pre2\n");
+      i++;		
+      pre2=TRUE;
+    } else
+    if (!strcmp(argv[i], "-pre3")) {
+//	  fprintf(stderr, "-pre3\n");
+      i++;		
+      pre3=TRUE;      
+    } else
+    if (!strcmp(argv[i], "-pre4")) {
+//	  fprintf(stderr, "-pre4\n");
+      i++;		
+      pre4=TRUE;          
+    } else          
+    if (!strcmp(argv[i], "-pre5")) {
+	  fprintf(stderr, "-pre5\n");
+      i++;		
+      pre5=TRUE;          
+    } else              
     if (!strcmp(argv[i], "-o")) {
       if (i==argc-1 || argv[i+1][0]=='-')
         p_err("-o need out file name");
@@ -180,7 +251,7 @@ int main(int argc, char **argv)
   char *phbuf8 = (char *)phbuf64;
   phokey_t *phbuf = (phokey_t *)phbuf64;
   u_int *phbuf32 = (u_int *)phbuf64;
-
+  
   while (!feof(fp)) {
     gboolean is_deleted = FALSE;
 	clen = 0;
@@ -198,12 +269,16 @@ int main(int argc, char **argv)
       clen = - clen;
       en_has_str = TRUE;
     }
+    
+    if (clen > 	MAX_PHRASE_LEN) {
+		fprintf(stderr,"too long %d", clen);
+	}
 
     fread(&usecount, sizeof(usecount_t), 1, fp);
     if (!pr_usecount)
       usecount = 0;
 
-    if (usecount < 0) {
+    if (usecount < 0 && !(pre2||pre3||pre4||pre5)) {
 	  dbg("is deleted clen:%d usecount:%d\n", clen, usecount);
       is_deleted = TRUE;
     }
@@ -289,15 +364,31 @@ fou:
       continue;
     }
 
-    if (no_pho) {
-      fprintf(fp_out, "%s\n", phbuf8);
-      continue;
-    }
+	if (minUseCount && usecount < minUseCount)
+		continue;
+
+	if (pre2 || pre3 || pre4 || pre5) {
+		if ((pre2 && (clen==1 || clen ==2)) || (pre3 && clen==3) || (pre4 && clen==4) || (pre5 && clen==5) )
+		{
+			p2ar=trealloc(p2ar, PRE5, p2arN+1);
+			PRE5 *p=&p2ar[p2arN++];
+			bzero(p, sizeof(PRE5));
+			for(int i=0;i<clen;i++)
+				p->k[i]=get_first_pho(phbuf[i]);
+//			p->k[1]=get_first_pho(phbuf[1]);
+			strcpy(p->s, tt);		
+			p->uc = usecount;
+			p->len = clen;
+		}
+		continue;
+	}	
 
 	if (phsz==1) {
 	  fprintf(fp_out, "%s", phbuf8);
 	} else {
       fprintf(fp_out, "%s ", tt);
+      
+      if (!no_pho)
       for(i=0;i<clen;i++) {
         if (phsz==2) {
           if (b_pinyin) {
@@ -326,6 +417,24 @@ fou:
 	fprintf(fp_out, phsz==1?"\t%d\n":" %d\n", usecount);
   }
 
+  if (pre2 || pre3 || pre4 || pre5) {
+	  qsort(p2ar, p2arN, sizeof(PRE5), qcmp_pre5_s);	  
+	  int np2arN=1;
+	  for(int i=1;i<p2arN;i++)
+		if (strcmp(p2ar[i].s, p2ar[i-1].s))
+			p2ar[np2arN++]=p2ar[i];
+	dbg("p2arN:%d np2arN:%d\n", p2arN, np2arN);
+	p2arN=np2arN;	
+	  qsort(p2ar, p2arN, sizeof(PRE5), qcmp_pre5);	  
+	  for(int i=0;i<p2arN;i++) {
+		  PRE5 *p = &p2ar[i];
+		  for(int j=0;j<p->len;j++)
+				fprintf(fp_out, "%s", phokey_to_str(p->k[j]));
+		fprintf(fp_out, " %s %d\n", p->s, p->uc);		
+	  }  
+  }  
+
+
 stop:
   fclose(fp);
   fclose(fp_out);
