@@ -231,12 +231,14 @@ int tsin_parse_recur(int start, TSIN_PARSE *out, short *r_match_phr_N, short *r_
 	  }
 
 #if 1
-//      if (match_len > plen)
 	  if (i != match_len) {
         continue;
       }
 #endif
 
+      if (match_len > plen)
+		continue;
+
       if (usecount <= maxusecount)
         continue;
 
@@ -384,7 +386,7 @@ void tsin_parse()
 #endif
   for(ofsi=i=0; out[i].len; i++) {
 #if DBG
-	dbg("out %d] %d\n", i, out[i].len);
+	dbg("out %d] len:%d\n", i, out[i].len);
 #endif
     int j, ofsj;
     int psta = ofsi;
