@@ -895,8 +895,9 @@ static gboolean tsin_seek_en_1(u_char *pho, int plen, int *ridx)
   usecount_t usecount;
   int hashi;
 
-#if 1
-  dbg("tsin_seek_en %d\n", plen);
+#if DEBUG
+  pho[plen]=0;
+  dbg("tsin_seek_en %s %d\n", pho, plen);
 #endif
 
   hashi= *((u_char *)pho);
@@ -921,7 +922,6 @@ static gboolean tsin_seek_en_1(u_char *pho, int plen, int *ridx)
   while (top <= bot) {
     mid=(top+bot)/ 2;
     load_tsin_entry_ex(th, mid, &len, &usecount, ss, NULL);
-
     u_char mlen;
     if (len > plen)
       mlen=plen;
@@ -930,6 +930,11 @@ static gboolean tsin_seek_en_1(u_char *pho, int plen, int *ridx)
 
     cmp=phokey_t_seq8(ss, pho, mlen);
 
+#if DEBUG && 0
+    ss[len]=0;
+    dbg("top:%d,%d mid:%d %s cmp:%d\n", top, bot, mid, ss, cmp);
+#endif
+
     if (!cmp && len < plen) {
 	  dbg("-2\n");
       cmp=-2;
