@@ -1743,17 +1743,21 @@ int tsin_pho_sel(int c)
   if (len) {
     prbuf();
     tss.current_page=tss.sel_pho=poo.ityp3_pho=0;
-    if (len == 1) {
+//    if (len == 1) 
+    {
       hide_selections_win();
       tss.ph_sta = -1;
 	  dbg("tss.c_len:%d %d\n",tss.c_len, gcin_buffer_select_char_auto_right);
 	  if (gcin_buffer_select_char_auto_right) {
-		   cursor_right();
+		   for(u_char i=0;i<len;i++)
+			cursor_right();
 	  }
-      return 0;
+      return len>1;
     }
+#if 0    
     else
       tss.ph_sta=-1;
+#endif      
 
     hide_selections_win();
 
