@@ -167,6 +167,27 @@ gboolean pharse_search(char *s)
   return bsearch(&s, phrase, phraseN, sizeof(char *), qcmp_str) != NULL;
 }
 
+gboolean phrase_prefix(char *s)
+{
+  int top=0, bot=phraseN-1;
+  int mid;
+  int len = strlen(s);
+  
+  while (top <= bot) {
+	  mid = (top+bot)/2;
+	  int d = strncmp(phrase[mid],s, len);
+	  if (d < 0)
+		top=mid+1;
+	else if (d > 0)		
+		bot = mid-1;
+		else
+			return TRUE;
+  }  
+  
+  return FALSE;
+}
+
+
 void all_wrap()
 {
   GtkTextIter mstart,mend;
@@ -191,8 +212,42 @@ static void cb_button_parse(GtkButton *button, gpointer user_data)
   dbg("parse char_count:%d\n", char_count);
 
   for(i=0; i < char_count; ) {
-    int len;
+    int len=2;
 
+      u_char txt[MAX_PHRASE_LEN*CH_SZ + 1];
+      int txtN=0, u8chN=0;
+      int k;
+      gboolean b_ignore=FALSE;
+      for(k=0; k<len && i+k < char_count; k++) {
+        GtkTextIter start,end;
+        gtk_text_buffer_get_iter_at_offset (buffer, &start, i+k);
+        gtk_text_buffer_get_iter_at_offset (buffer, &end, i+k+1);
+        char *utf8 = gtk_text_buffer_get_text(buffer, &start, &end, FALSE);
+
+        if (!(utf8[0] & 128))
+          b_ignore = TRUE;
+
+        int wn = strlen(utf8);
+
+        memcpy(&txt[txtN], utf8, wn);
+
+        txtN+= wn;
+        u8chN++;
+      }
+
+	  if (b_ignore) {
+		i++;
+	    continue;
+	  }  
+
+     txt[txtN] = 0;
+//     dbg("txt %s\n", txt);     
+     if (!phrase_prefix((char *)txt)) {
+       i++;
+//       dbg("skip\n");
+       continue;
+     }  
+     
     for(len=MAX_PHRASE_LEN; len>=2 ; len--) {
       u_char txt[MAX_PHRASE_LEN*CH_SZ + 1];
       int txtN=0, u8chN=0;
@@ -228,14 +283,20 @@ static void cb_button_parse(GtkButton *button, gpointer user_data)
 
       GtkTextIter mstart,mend;
 
+	  static char* bgs[]={"red_background","green_background","blue_background"};
+#define bgsN 3
+	  int idx=len-2;
+	  if (idx>=bgsN)
+		idx=bgsN-1;
+		char *bg = bgs[idx];
       gtk_text_buffer_get_iter_at_offset (buffer, &mstart, i);
       gtk_text_buffer_get_iter_at_offset (buffer, &mend, i+len);
-      gtk_text_buffer_apply_tag_by_name (buffer, "blue_background", &mstart, &mend);
+      gtk_text_buffer_apply_tag_by_name (buffer, bg, &mstart, &mend);
 #if 1
       // why do I have to repeat this
       gtk_text_buffer_get_iter_at_offset (buffer, &mstart, i);
       gtk_text_buffer_get_iter_at_offset (buffer, &mend, i+len);
-      gtk_text_buffer_apply_tag_by_name (buffer, "blue_background", &mstart, &mend);
+      gtk_text_buffer_apply_tag_by_name (buffer, bg, &mstart, &mend);
 #endif
       gdk_flush();
     }
@@ -496,8 +557,11 @@ int main(int argc, char **argv)
 
   gtk_text_buffer_set_text (buffer, text, -1);
 
-  gtk_text_buffer_create_tag (buffer,
-     "blue_background", "background", "blue", "foreground", "white", NULL);
+  gtk_text_buffer_create_tag (buffer,"red_background", "background", "red", "foreground", "white", NULL);
+
+  gtk_text_buffer_create_tag (buffer,"green_background", "background", "green", "foreground", "white", NULL);
+
+  gtk_text_buffer_create_tag (buffer,"blue_background", "background", "blue", "foreground", "white", NULL);
 
   gtk_text_buffer_create_tag (buffer, "char_wrap",
 			      "wrap_mode", GTK_WRAP_CHAR, NULL);
