@@ -382,3 +382,11 @@ void box_warn(char *fmt,...)
   gtk_widget_destroy (dialog);
 }
 #endif
+
+
+#if UNIX
+u_char isX11() {
+	char *s = getenv("XDG_SESSION_TYPE");
+	return s==NULL || strcmp(s, "wayland");
+}
+#endif
