@@ -3,6 +3,10 @@ void p_err_no_alter(char *fmt,...);
 void box_warn(char *fmt,...);
 char *sys_err_strA();
 
+#if UNIX
+u_char isX11();
+#endif
+
 #if DEBUG
 void __gcin_dbg_(const char *fmt,...);
 #if GCIN_MODULE
