@@ -24,7 +24,11 @@ static GtkWidget *box_gtab_im_name;
 static GtkWidget *hbox_row2;
 static GtkWidget *label_page;
 static GtkWidget *label_edit;
+#if GTK_CHECK_VERSION(2,91,6)
+static GdkRGBA better_color={1.0, 0, 0, 1.0};  // red
+#else
 static GdkColor better_color;
+#endif
 gboolean last_cursor_off;
 
 void set_label_space(GtkWidget *label);
@@ -241,14 +245,20 @@ void disp_gtab_sel(char *s)
 
 void set_key_codes_label(char *s, int better)
 {
-//  dbg("set_key_codes_label %s %x\n", s, label_key_codes);
+  dbg("set_key_codes_label %s %p\n", s, label_key_codes);
+  gboolean has_s = s && s[0];
+  
+  if (has_s){
+	strcpy(str_key_codes, s);
+  }
+  
   if (!label_key_codes)
     return;
 #if WIN32
   if (test_mode)
     return;
 #endif
-  if (s && strlen(s)) {
+  if (s && s[0]) {
     if (hbox_row2 && (!gtab_hide_row2 || ggg.wild_mode
 #if WIN32 || 1
         || (str_key_codes[0])
@@ -266,9 +276,13 @@ void set_key_codes_label(char *s, int better)
 #if !GTK_CHECK_VERSION(2,91,6)
     gtk_widget_modify_fg(label_key_codes, GTK_STATE_NORMAL, &better_color);
 #else
+#if 0
     GdkRGBA rgbfg;
-    gdk_rgba_parse(&rgbfg, gdk_color_to_string(&better_color));
-    gtk_widget_override_color(label_key_codes, GTK_STATE_FLAG_NORMAL, &rgbfg);
+    gchar *s=gdk_color_to_string(&better_color);
+    gdk_rgba_parse(&rgbfg, s);
+    g_free(s);
+#endif    
+    gtk_widget_override_color(label_key_codes, GTK_STATE_FLAG_NORMAL, &better_color);
 #endif
   } else
 #if !GTK_CHECK_VERSION(2,91,6)
@@ -278,15 +292,17 @@ void set_key_codes_label(char *s, int better)
 #endif
 
   gtk_label_set_text(GTK_LABEL(label_key_codes), s);
-  if (s && s[0])
+  if (has_s) {
     gtk_widget_show(label_key_codes);
-
+  }
 #if WIN32 || 1
   better_key_codes = better;
+#if 0  
   if (s && s != str_key_codes)
     strcpy(str_key_codes, s);
   else
     str_key_codes[0]=0;
+#endif    
 #endif
 }
 
@@ -623,7 +639,9 @@ void create_win_gtab_gui_simple()
       gtk_container_add (GTK_CONTAINER (frame_gtab), label_gtab);
   }
 
-  label_key_codes  = gtk_label_new(NULL);
+  label_key_codes  = gtk_label_new(NULL);    
+  gtk_label_set_text(label_key_codes, str_key_codes);
+  
 #if 0
   gtk_label_set_selectable(GTK_LABEL(label_key_codes), TRUE);
   mod_bg_all(label_key_codes, NULL);
@@ -665,7 +683,9 @@ static void create_win_gtab_gui()
   current_gtab_in_row1 = gtab_in_row1;
   current_gtab_vertical_select = gtab_vertical_select_on();
   current_gcin_inner_frame = gcin_inner_frame;
+#if !GTK_CHECK_VERSION(2,91,6)
   gdk_color_parse("red", &better_color);
+#endif  
   disp_gbuf();
 }
 
@@ -743,6 +763,7 @@ static void destroy_top_bin()
 {
   if (!top_bin)
     return;
+  dbg("destroy_top_bin\n");
   gtk_widget_destroy(top_bin);
   top_bin = NULL;
   hbox_row2 = NULL;
@@ -777,7 +798,7 @@ void hide_win_gtab()
   if (!gwin_gtab)
     return;
 
-//  dbg("hide_win_gtab\n");
+  dbg("hide_win_gtab\n");
   if (gwin_gtab) {
     if (destroy_window)
       destroy_win_gtab();
@@ -898,6 +919,7 @@ void hide_gtab_pre_sel()
     hide_selections_win();
 
 //  dbg("hide_gtab_pre_sel %d\n", tss.ctrl_pre_sel);
+  ggg.pg_idx = 0;
   tss.pre_selN = 0;
   tss.ctrl_pre_sel = FALSE;
   if (label_gtab_pre_sel)
